#!/usr/bin/python
import xml.etree.ElementTree as ET
import sys
import fpdf
import csv
from pathlib import Path
from xml.dom import XML_NAMESPACE, minidom
from tabulate import tabulate

def parseXML(xml_file):
	# Load and parse XML file 
	tree = ET.parse(xml_file)
	root = tree.getroot()
	# Set namespace
	namespace = {"qlc": "http://www.qlcplus.org/Workspace"}
	cap=['Fabricant', 'Model', 'ID Fixture', 'Nom', 'Universe', 'Adreça Ini', 'Adreça Fi', 'Canals']
	cap=['Manufacturer', 'Model', 'ID Fixture', 'Name', 'Universe', 'Address', 'Address Final', 'Channels']
	fixtures=[]
	for fixture in root.findall(".//qlc:Fixture", namespace):
		manufacturer = fixture.find("qlc:Manufacturer", namespace).text
		model = fixture.find("qlc:Model", namespace).text
		fixture_id = fixture.find("qlc:ID", namespace).text
		fixture_name = fixture.find("qlc:Name", namespace).text
		universe = fixture.find("qlc:Universe", namespace).text
		address = int(fixture.find("qlc:Address", namespace).text)+1
		channels = fixture.find("qlc:Channels", namespace).text
		addressend = int(fixture.find("qlc:Address", namespace).text)+int(fixture.find("qlc:Channels", namespace).text)
		dades=[manufacturer, model , fixture_id, fixture_name, universe, address, addressend, channels]
		fixtures.append(dades)
	fixtures.sort(key=lambda fixtures: fixtures[5])
	fixtures.insert(0, cap)
	outfile = xml_file.split(".")[0]+'.csv'
	outpath= Path(xml_file).resolve().parent
	print (outpath)
	csvname = Path(xml_file).stem+'.csv'
	print (csvname)
	outfile=str(outpath)+'/'+csvname
	print (outfile)
	Patch_data = open(outfile, 'w')
	csvwriter = csv.writer(Patch_data)
	for f in fixtures:
		csvwriter.writerow(f)
	Patch_data.close()
	
def main():
	if len(sys.argv) >= 2:
		# ~ print(sys.argv)
		filename = sys.argv[1]
		# ~ print (filename)
		parseXML(filename)
	else:
		print ("Please specify a QLC+ Workspace (.qxw) file to read")
if __name__ == "__main__":
	main()
